hyperspy\.tests\.model package
==============================

Submodules
----------

hyperspy\.tests\.model\.test\_chi\_squared module
-------------------------------------------------

.. automodule:: hyperspy.tests.model.test_chi_squared
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.tests\.model\.test\_component module
----------------------------------------------

.. automodule:: hyperspy.tests.model.test_component
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.tests\.model\.test\_components module
-----------------------------------------------

.. automodule:: hyperspy.tests.model.test_components
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.tests\.model\.test\_components2D module
-------------------------------------------------

.. automodule:: hyperspy.tests.model.test_components2D
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.tests\.model\.test\_edsmodel module
---------------------------------------------

.. automodule:: hyperspy.tests.model.test_edsmodel
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.tests\.model\.test\_eelsmodel module
----------------------------------------------

.. automodule:: hyperspy.tests.model.test_eelsmodel
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.tests\.model\.test\_fancy\_indexing module
----------------------------------------------------

.. automodule:: hyperspy.tests.model.test_fancy_indexing
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.tests\.model\.test\_fit\_component module
---------------------------------------------------

.. automodule:: hyperspy.tests.model.test_fit_component
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.tests\.model\.test\_model module
------------------------------------------

.. automodule:: hyperspy.tests.model.test_model
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.tests\.model\.test\_model\_as\_dictionary module
----------------------------------------------------------

.. automodule:: hyperspy.tests.model.test_model_as_dictionary
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.tests\.model\.test\_model\_selection\_criteria module
---------------------------------------------------------------

.. automodule:: hyperspy.tests.model.test_model_selection_criteria
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.tests\.model\.test\_model\_storing module
---------------------------------------------------

.. automodule:: hyperspy.tests.model.test_model_storing
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.tests\.model\.test\_parameter module
----------------------------------------------

.. automodule:: hyperspy.tests.model.test_parameter
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.tests\.model\.test\_set\_parameter\_state module
----------------------------------------------------------

.. automodule:: hyperspy.tests.model.test_set_parameter_state
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.tests\.model\.test\_set\_parameter\_value module
----------------------------------------------------------

.. automodule:: hyperspy.tests.model.test_set_parameter_value
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: hyperspy.tests.model
    :members:
    :undoc-members:
    :show-inheritance:
